/*!
 * @file element_2d.h
 * @brief Definition of the 2D elements rendered on top through the GraphicsEngine
*/

#ifndef _ELEMENT_2D_H
#define _ELEMENT_2D_H

#include "base_object.h"

// FORWARD DECLARATION
class PNode;

//!< An enumerator defining the Depth of a 2D-element.
typedef enum
{
  E2D_TOP,                             //!< Will be rendered on top of everything else
  E2D_MEDIUM,                          //!< Will be rendered on the medium Layer.
  E2D_BOTTOM,                          //!< Will be rendered on the bottom Layer
  E2D_BELOW_ALL                        //!< Will be rendered below the 3D-scene. @todo make this work.
} E2DLayer;


typedef enum
{
  ELEM2D_ALIGN_LEFT,
  ELEM2D_ALIGN_RIGHT,
  ELEM2D_ALIGN_CENTER,
  ELEM2D_ALIGN_SCREEN_CENTER
} ELEM2D_ALIGNMENT;


//! A class for ...
class Element2D : public BaseObject {

 public:
  Element2D();
  virtual ~Element2D();


  void setPosition(int xCoord, int yCoord);
  void setLayer(E2DLayer layer);


  void positioning();
  virtual void draw() const = NULL;

 private:
   bool               visible;
   int                position2D[2];    //!< X-coord, Y-Coord
   E2DLayer           layer;

   ELEM2D_ALIGNMENT   alignment;
   PNode*             bindNode;         //!< a node over which to display this 2D-element
};


#endif /* _ELEMENT_2D_H */
